@@ -170,7 +170,58 @@ check_old_version (void)
 void
 on_druid_help_clicked (GtkWidget *w, gpointer data)
 {
-	gnome_help_display ("bug-buddy", NULL, NULL);
+	GError *error = NULL;
+	switch (druid_data.state) {
+	case STATE_INTRO:
+		gnome_help_display ("bug-buddy", "welcome", &error);
+		break;
+	case STATE_GDB:
+		gnome_help_display ("bug-buddy", "reporting-crash", &error);
+		break;
+	case STATE_PRODUCT:
+		gnome_help_display ("bug-buddy", "product", &error);
+		break;
+	case STATE_COMPONENT:
+		gnome_help_display ("bug-buddy", "component", &error);
+		break;
+	case STATE_MOSTFREQ:
+		gnome_help_display ("bug-buddy", "frequent-bugs", &error);
+		break;
+	case STATE_DESC:
+		gnome_help_display ("bug-buddy", "description", &error);
+		break;
+	case STATE_EMAIL_CONFIG:
+		gnome_help_display ("bug-buddy", "mail-config", &error);
+		break;
+	case STATE_EMAIL:
+		gnome_help_display ("bug-buddy", "confirmation", &error);
+		break;
+	case STATE_FINISHED:
+		gnome_help_display ("bug-buddy", "summary", &error);
+		break;
+	case STATE_LAST:
+	default:
+		gnome_help_display ("bug-buddy", NULL, &error);
+		break;
+	}
+
+	if (error) {
+		GtkWidget *msg_dialog;
+		msg_dialog = gtk_message_dialog_new (GTK_WINDOW(w),
+						     GTK_DIALOG_DESTROY_WITH_PARENT,
+						     GTK_MESSAGE_ERROR,
+						     GTK_BUTTONS_CLOSE,
+						     "There was an error displaying help: %s",
+						     error->message);
+
+		g_signal_connect (G_OBJECT (msg_dialog), "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+
+		gtk_window_set_resizable (GTK_WINDOW (msg_dialog), FALSE);
+		gtk_widget_show (msg_dialog);
+		 g_error_free (error);
+	}
 }
 
 void
@@ -188,6 +239,7 @@ on_druid_about_clicked (GtkWidget *button, gpointer data)
 		"Telsa Gwynne  <hobbit@aloss.ukuu.org.uk>",
 		"Kevin Conder  <kevin@kevindumpscore.com>",
 		"Eric Baudais  <baudais@kkpsi.org>",
+		"Shaun McCance <shaunm@gnome.org>",
 		NULL
 	};
 
